/*
 * Copyright 2004-2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hdiv.webflow.web.servlet.tags.form;

import javax.servlet.jsp.JspException;

/**
 * Databinding-aware JSP tag for rendering an HTML '<code>form</code>' whose
 * inner elements are bound to properties on a
 * {@link #setCommandName command object}.
 * 
 * Adds automatically the _flowExecutionKey hidden parameter to the forms of 
 * webflow applications.
 * 
 * @author Gorka Vicente
 * @since HDIV 2.0.3
 * @see org.hdiv.web.servlet.tags.form.FormTagHDIV
 */
public class FormTagHDIV extends org.hdiv.web.servlet.tags.form.FormTagHDIV {

	/**
	 * By default clients can send the key of a flow execution to be resumed
	 * using an argument with this name ("_flowExecutionKey").
	 */
	private static final String FLOW_EXECUTION_KEY_ARGUMENT_NAME = "_flowExecutionKey";

	
	/**
	 * Adds new parameters to the form.
	 */
	public void addExtraParameters() throws JspException {

		this.addFlowExecutionParameter();
		super.addExtraParameters();
	}

	/**
	 * Adds flow execution key (_flowExecutionKey) as parameter.
	 */
	protected void addFlowExecutionParameter() throws JspException {

		String flowExceutionKey = (String) this.pageContext.getRequest().getAttribute("flowExecutionKey");

		if (flowExceutionKey != null) {

			String composedValue = super.getDataComposer().compose(FLOW_EXECUTION_KEY_ARGUMENT_NAME, flowExceutionKey, false);
			this.getTagWriter().appendValue(this.generateHiddenTag(FLOW_EXECUTION_KEY_ARGUMENT_NAME, composedValue));
		}
	}

	/**
	 * @returns Returns true if parameter <code>param</code> must be ignored.
	 *          False otherwise.
	 */
	protected boolean ignoreParameter(String param) {

		if (param.equalsIgnoreCase(FLOW_EXECUTION_KEY_ARGUMENT_NAME)) {
			return true;
		}

		return super.ignoreParameter(param);
	}
}
